#
# spec file for package mpfr (Version 3.0.1)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild

%define debug_package_requires libmpfr4 = %{version}-%{release}

Name:           mpfr
BuildRequires:  gmp-devel
License:        LGPLv2.1+
Group:          Development/Libraries/C and C++
AutoReqProv:    on
Version:        3.0.1
Release:        1
Summary:        The MPFR multiple-precision floating-point library
Url:            http://www.mpfr.org/
Source:         mpfr-%{version}.tar.bz2
Source2:        baselibs.conf
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library.

The main goal of MPFR is to provide a library for multiple-precision
floating-point computation which is both efficient and has a
well-defined semantics. It copies the good ideas from the ANSI/IEEE-754
standard for double-precision floating-point arithmetic (53-bit
mantissa).



Authors:
--------
    Guillaume Hanrot
    Paul Zimmermann
    Vincent Lefvre
    Patrick Plissier

%package -n libmpfr4
License:        LGPLv2.1+
Summary:        MPFR multiple-precision floating-point computation shared library
Group:          Development/Libraries/C and C++
AutoReqProv:    on
# in openSUSE 10.2 and 10.3 the shared library was in the mpfr package itself
Provides:       mpfr = 2.3.0
Obsoletes:      mpfr < 2.3.0

%description -n libmpfr4
The MPFR library is a C library for multiple-precision floating-point
computations with exact rounding (also called correct rounding). It is
based on the GMP multiple-precision library.



Authors:
--------
    Guillaume Hanrot
    Paul Zimmermann
    Vincent Lefvre
    Patrick Plissier

%package devel
License:        LGPLv2.1+
Summary:        MPFR multiple-precision floating-point library development files
Group:          Development/Libraries/C and C++
Requires:       libmpfr4 = %{version} gmp-devel
Provides:       gmp-devel:/usr/lib/libmpfr.a
AutoReqProv:    on
PreReq:         %install_info_prereq

%description devel
MPFR multiple-precision floating-point library development files



Authors:
--------
    Guillaume Hanrot
    Paul Zimmermann
    Vincent Lefvre
    Patrick Plissier

%prep
%setup -q

%build
%configure \
%if 0%{suse_version} > 1000
%ifnarch %sparc hppa
	--enable-thread-safe \
%endif
%endif
	--enable-shared \
	--docdir=%{_docdir}/mpfr
make %{?_smp_mflags}

%check
make check %{?_smp_mflags}

%install
%makeinstall
rm ${RPM_BUILD_ROOT}%{_libdir}/lib*.la

%post -n libmpfr4
%run_ldconfig

%post devel
%install_info --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%postun -n libmpfr4
%run_ldconfig

%postun devel
%install_info_delete --info-dir=%{_infodir} %{_infodir}/%{name}.info.gz

%clean
rm -rf $RPM_BUILD_ROOT

%files -n libmpfr4
%defattr(-,root,root)
%{_libdir}/libmpfr.so.4*

%files devel
%defattr(-,root,root)
%doc %{_docdir}/mpfr
%doc %{_infodir}/mpfr.info.gz
%{_libdir}/libmpfr.a
%{_libdir}/libmpfr.so
%{_prefix}/include/mpf2mpfr.h
%{_prefix}/include/mpfr.h

%changelog
